@@ -16,7 +16,7 @@ class EntryNotFound(BaseAxewException):
 
 
 class InvalidParams(BaseAxewException):
-    """Require at-least code or error."""
+    """An entry requires at-least code."""
 
 
 class ValidationError(BaseAxewException):
@@ -25,3 +25,11 @@ class ValidationError(BaseAxewException):
     def __init__(self, var, size):
         super().__init__()
         self.message += f" {var} needs to be shorter then {size}."
+
+
+class BadRequest(BaseAxewException):
+    """Something went wrong."""
+
+    def __init__(self, message):
+        super().__init__()
+        self.message = message
